@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: authenticate
 version: 1.3.3
-id: authenticate-1.3.3-c7cd7dbf777a77b23e23ff23b790e7d4
-key: authe_1u6B4wfvlys1vgKxkMqKtG
+id: authenticate-1.3.3-4c5690f1ea7aaebe284c971d7222338d
+key: authe_0fH33HUWGJh2TIlwyCPsTo
 license: BSD3
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -23,7 +23,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/authenticate-1.3.3
-hs-libraries: HSauthenticate-1.3.3-1u6B4wfvlys1vgKxkMqKtG
+hs-libraries: HSauthenticate-1.3.3-0fH33HUWGJh2TIlwyCPsTo
 depends:
     aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
     attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
@@ -31,18 +31,18 @@ depends:
     blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     case-insensitive-1.2.0.6-c6baeb35be7a5ef7e8151f5e00d87f59
-    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
+    conduit-1.2.6.4-9cbf21b79aba616188d311eceb1fecef
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    http-conduit-2.1.8-0cd87eafc953cbe4f675bdf50a2df8e2
+    http-conduit-2.1.9-a114e1e30c63561e9380f63d9f83e5a8
     http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
-    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
+    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
     network-uri-2.6.1.0-0e39aca8530572505c01ef548c540bd6
-    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
-    tagstream-conduit-0.5.5.3-c659b13637e6399e888788db23405b6c
+    resourcet-1.1.7.3-7c6bcbec462b80120c27277d178fc6db
+    tagstream-conduit-0.5.5.3-263ed71b63ed196273744e4745b0360d
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
-    xml-conduit-1.3.4-2cb0835929c2dc7743cd241414dfd06a
+    xml-conduit-1.3.4.1-75d80fe52680bbdca276c9f509509d3e
 haddock-interfaces: /usr/share/doc/haskell-authenticate/html/authenticate.haddock
 haddock-html: /usr/share/doc/haskell-authenticate/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
